# encoding: UTF-8
#
# Copyright 2012, by Mark Jason Grundman
#
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided that the above
# copyright notice appear in all copies.

# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
# -----------------------------------------------------------------------------
#
#	Name        :   MJGrundman_SPGears.rb
#	Description :   Draws various types of gears with involute tooth profiles.
#	Menu Item   :   Plugins (Extensions) -> SP Gears (MJG)
#	Context Menu:   NONE
#	Date        :   2021-10-26
#	Version     :   1.3.0
#
#	Doug Herrrman's gear plugin ('gear.3.rb' created in 2006) does a great job
# of creating a 2D gear profile.  Unfortunately when used to create gears for
# SketchyPhysics (SP), it did not create accurate collision geometry.
# Doug's plug-in inspired (and provided a basis for) this re-work of the
# concept, which solves the collision geometry problems when used with SP.
#
#	This is a great utility for creating gears in 'static' drawings, too.
# I tried to cover as many common gear styles and variations as possible.
#
#	v1.3 : 2021-10-26  by Dan Rathbun
#      - Properly namespace wrapped and packaged as a RBZ extension archive.
#
#	v1.2 : 2012-06-28
#      - revisions and additions
#			 - added root fillets
#			 - added rim and web to base profile
#			 - modified involute calculations to maintain curve detail as size decreases
#			
#	v1.1 - minor bug fix
#
#	v1.0 - initial release
#
#-----------------------------------------------------------------------------/

# These files are preloaded for SU2014 and higher:
require 'sketchup.rb' unless defined?($loaded_files)
require 'extensions.rb' unless defined?(SketchupExtension)

module MJGrundman
  module SPGears

    EXTENSION ||= SketchupExtension.new(
      "MJ Grundman's Gears for Sketchy Physics",
      'MJGrudman_SPGears/SPGears_mjg'
    )

    # Property setter calls for the extension:
    EXTENSION.instance_eval do
      self.creator = 'Mark Jason Grundman'
      self.version = '1.3'
      self.copyright = '©2012 released under MIT License'
      self.description = 'A utility for creating gears in both static '<<
      'models and Sketchy Physics models requiring collision geometry.'
      # Register and load the extension: 
      Sketchup.register_extension( self, true )
    end

  end # extension submodule
end # author namespace module